2 ms·
It's about 3-4x faster with the initial implementation: foreach(range(1,20) as $j) foreach(range(1,1000000) as $i) strval($i); Running
by meritt 6y ago
It's about 3-4x faster with the initial implementation:
foreach(range(1,20) as $j)
foreach(range(1,1000000) as $i)
strval($i);
Running on my low-end EC2 box:
php7.3 py.php == 1.258s
python2 py.py == 3.714s
python3 py.py == 4.530s